Class: Aws::ServiceDiscovery::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServiceDiscovery::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-servicediscovery/client.rb,
sig/client.rbs
Overview
An API client for ServiceDiscovery. To construct a client, you need to configure a :region and :credentials.
client = Aws::ServiceDiscovery::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateHttpNamespaceResponseSuccess, _CreatePrivateDnsNamespaceResponseSuccess, _CreatePublicDnsNamespaceResponseSuccess, _CreateServiceResponseSuccess, _DeleteNamespaceResponseSuccess, _DeleteServiceAttributesResponseSuccess, _DeleteServiceResponseSuccess, _DeregisterInstanceResponseSuccess, _DiscoverInstancesResponseSuccess, _DiscoverInstancesRevisionResponseSuccess, _GetInstanceResponseSuccess, _GetInstancesHealthStatusResponseSuccess, _GetNamespaceResponseSuccess, _GetOperationResponseSuccess, _GetServiceAttributesResponseSuccess, _GetServiceResponseSuccess, _ListInstancesResponseSuccess, _ListNamespacesResponseSuccess, _ListOperationsResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterInstanceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateHttpNamespaceResponseSuccess, _UpdatePrivateDnsNamespaceResponseSuccess, _UpdatePublicDnsNamespaceResponseSuccess, _UpdateServiceAttributesResponseSuccess, _UpdateServiceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_http_namespace(params = {}) ⇒ Types::CreateHttpNamespaceResponse
Creates an HTTP namespace.
-
#create_private_dns_namespace(params = {}) ⇒ Types::CreatePrivateDnsNamespaceResponse
Creates a private namespace based on DNS, which is visible only inside a specified Amazon VPC.
-
#create_public_dns_namespace(params = {}) ⇒ Types::CreatePublicDnsNamespaceResponse
Creates a public namespace based on DNS, which is visible on the internet.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service.
-
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes a namespace from the current account.
-
#delete_service(params = {}) ⇒ Struct
Deletes a specified service and all associated service attributes.
-
#delete_service_attributes(params = {}) ⇒ Struct
Deletes specific attributes associated with a service.
-
#deregister_instance(params = {}) ⇒ Types::DeregisterInstanceResponse
Deletes the Amazon RouteĀ 53 DNS records and health check, if any, that Cloud Map created for the specified instance.
-
#discover_instances(params = {}) ⇒ Types::DiscoverInstancesResponse
Discovers registered instances for a specified namespace and service.
-
#discover_instances_revision(params = {}) ⇒ Types::DiscoverInstancesRevisionResponse
Discovers the increasing revision associated with an instance.
-
#get_instance(params = {}) ⇒ Types::GetInstanceResponse
Gets information about a specified instance.
-
#get_instances_health_status(params = {}) ⇒ Types::GetInstancesHealthStatusResponse
Gets the current health status (
Healthy,Unhealthy, orUnknown) of one or more instances that are associated with a specified service. -
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets information about a namespace.
-
#get_operation(params = {}) ⇒ Types::GetOperationResponse
Gets information about any operation that returns an operation ID in the response, such as a
CreateHttpNamespacerequest. -
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets the settings for a specified service.
-
#get_service_attributes(params = {}) ⇒ Types::GetServiceAttributesResponse
Returns the attributes associated with a specified service.
-
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists summary information about the instances that you registered by using a specified service.
-
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists summary information about the namespaces that were created by the current Amazon Web Services account and shared with the current Amazon Web Services account.
-
#list_operations(params = {}) ⇒ Types::ListOperationsResponse
Lists operations that match the criteria that you specify.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists summary information for all the services that are associated with one or more namespaces.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource.
-
#register_instance(params = {}) ⇒ Types::RegisterInstanceResponse
Creates or updates one or more records and, optionally, creates a health check based on the settings in a specified service.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_http_namespace(params = {}) ⇒ Types::UpdateHttpNamespaceResponse
Updates an HTTP namespace.
-
#update_instance_custom_health_status(params = {}) ⇒ Struct
Submits a request to change the health status of a custom health check to healthy or unhealthy.
-
#update_private_dns_namespace(params = {}) ⇒ Types::UpdatePrivateDnsNamespaceResponse
Updates a private DNS namespace.
-
#update_public_dns_namespace(params = {}) ⇒ Types::UpdatePublicDnsNamespaceResponse
Updates a public DNS namespace.
-
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Submits a request to perform the following operations:.
-
#update_service_attributes(params = {}) ⇒ Struct
Submits a request to update a specified service to add service-level attributes.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-servicediscovery/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3747 3748 3749 |
# File 'lib/aws-sdk-servicediscovery/client.rb', line 3747 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3750 3751 3752 |
# File 'lib/aws-sdk-servicediscovery/client.rb', line 3750 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-servicediscovery/client.rb', line 3720 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServiceDiscovery') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-servicediscovery' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#create_http_namespace(params = {}) ⇒ Types::CreateHttpNamespaceResponse
Creates an HTTP namespace. Service instances registered using an HTTP
namespace can be discovered using a DiscoverInstances request but
can't be discovered using DNS.
For the current quota on the number of namespaces that you can create using the same Amazon Web Services account, see Cloud Map quotas in the Cloud Map Developer Guide.
87 |
# File 'sig/client.rbs', line 87
def create_http_namespace: (
|
#create_private_dns_namespace(params = {}) ⇒ Types::CreatePrivateDnsNamespaceResponse
Creates a private namespace based on DNS, which is visible only inside
a specified Amazon VPC. The namespace defines your service naming
scheme. For example, if you name your namespace example.com and name
your service backend, the resulting DNS name for the service is
backend.example.com. Service instances that are registered using a
private DNS namespace can be discovered using either a
DiscoverInstances request or using DNS. For the current quota on the
number of namespaces that you can create using the same Amazon Web
Services account, see Cloud Map quotas in the Cloud Map
Developer Guide.
105 |
# File 'sig/client.rbs', line 105
def create_private_dns_namespace: (
|
#create_public_dns_namespace(params = {}) ⇒ Types::CreatePublicDnsNamespaceResponse
Creates a public namespace based on DNS, which is visible on the
internet. The namespace defines your service naming scheme. For
example, if you name your namespace example.com and name your
service backend, the resulting DNS name for the service is
backend.example.com. You can discover instances that were registered
with a public DNS namespace by using either a DiscoverInstances
request or using DNS. For the current quota on the number of
namespaces that you can create using the same Amazon Web Services
account, see Cloud Map quotas in the Cloud Map Developer Guide.
The CreatePublicDnsNamespace API operation is not supported in the
Amazon Web Services GovCloud (US) Regions.
131 |
# File 'sig/client.rbs', line 131
def create_public_dns_namespace: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates a service. This action defines the configuration for the following entities:
-
For public and private DNS namespaces, one of the following combinations of DNS records in Amazon RouteĀ 53:
-
A -
AAAA -
AandAAAA -
SRV -
CNAME -
Optionally, a health check
After you create the service, you can submit a RegisterInstance request, and Cloud Map uses the values in the configuration to create the specified entities.
For the current quota on the number of instances that you can register using the same namespace and using the same service, see Cloud Map quotas in the Cloud Map Developer Guide.
156 |
# File 'sig/client.rbs', line 156
def create_service: (
|
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes a namespace from the current account. If the namespace still contains one or more services, the request fails.
194 |
# File 'sig/client.rbs', line 194
def delete_namespace: (
|
#delete_service(params = {}) ⇒ Struct
Deletes a specified service and all associated service attributes. If the service still contains one or more registered instances, the request fails.
203 |
# File 'sig/client.rbs', line 203
def delete_service: (
|
#delete_service_attributes(params = {}) ⇒ Struct
Deletes specific attributes associated with a service.
212 |
# File 'sig/client.rbs', line 212
def delete_service_attributes: (
|
#deregister_instance(params = {}) ⇒ Types::DeregisterInstanceResponse
Deletes the Amazon RouteĀ 53 DNS records and health check, if any, that Cloud Map created for the specified instance.
223 |
# File 'sig/client.rbs', line 223
def deregister_instance: (
|
#discover_instances(params = {}) ⇒ Types::DiscoverInstancesResponse
Discovers registered instances for a specified namespace and service.
You can use DiscoverInstances to discover instances for any type of
namespace. DiscoverInstances returns a randomized list of instances
allowing customers to distribute traffic evenly across instances. For
public and private DNS namespaces, you can also use DNS queries to
discover instances.
235 |
# File 'sig/client.rbs', line 235
def discover_instances: (
|
#discover_instances_revision(params = {}) ⇒ Types::DiscoverInstancesRevisionResponse
Discovers the increasing revision associated with an instance.
251 |
# File 'sig/client.rbs', line 251
def discover_instances_revision: (
|
#get_instance(params = {}) ⇒ Types::GetInstanceResponse
Gets information about a specified instance.
264 |
# File 'sig/client.rbs', line 264
def get_instance: (
|
#get_instances_health_status(params = {}) ⇒ Types::GetInstancesHealthStatusResponse
Gets the current health status (Healthy, Unhealthy, or Unknown)
of one or more instances that are associated with a specified service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
276 |
# File 'sig/client.rbs', line 276
def get_instances_health_status: (
|
#get_namespace(params = {}) ⇒ Types::GetNamespaceResponse
Gets information about a namespace.
289 |
# File 'sig/client.rbs', line 289
def get_namespace: (
|
#get_operation(params = {}) ⇒ Types::GetOperationResponse
Gets information about any operation that returns an operation ID in
the response, such as a CreateHttpNamespace request.
299 |
# File 'sig/client.rbs', line 299
def get_operation: (
|
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets the settings for a specified service.
310 |
# File 'sig/client.rbs', line 310
def get_service: (
|
#get_service_attributes(params = {}) ⇒ Types::GetServiceAttributesResponse
Returns the attributes associated with a specified service.
320 |
# File 'sig/client.rbs', line 320
def get_service_attributes: (
|
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists summary information about the instances that you registered by using a specified service.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
332 |
# File 'sig/client.rbs', line 332
def list_instances: (
|
#list_namespaces(params = {}) ⇒ Types::ListNamespacesResponse
Lists summary information about the namespaces that were created by the current Amazon Web Services account and shared with the current Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
345 |
# File 'sig/client.rbs', line 345
def list_namespaces: (
|
#list_operations(params = {}) ⇒ Types::ListOperationsResponse
Lists operations that match the criteria that you specify.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
364 |
# File 'sig/client.rbs', line 364
def list_operations: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists summary information for all the services that are associated with one or more namespaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
383 |
# File 'sig/client.rbs', line 383
def list_services: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource.
401 |
# File 'sig/client.rbs', line 401
def list_tags_for_resource: (
|
#register_instance(params = {}) ⇒ Types::RegisterInstanceResponse
Creates or updates one or more records and, optionally, creates a
health check based on the settings in a specified service. When you
submit a RegisterInstance request, the following occurs:
-
For each DNS record that you define in the service that's specified by
ServiceId, a record is created or updated in the hosted zone that's associated with the corresponding namespace. -
If the service includes
HealthCheckConfig, a health check is created based on the settings in the health check configuration. -
The health check, if any, is associated with each of the new or updated records.
One RegisterInstance request must complete before you can submit
another request and specify the same service ID and instance ID.
For more information, see CreateService.
When Cloud Map receives a DNS query for the specified DNS name, it returns the applicable value:
-
If the health check is healthy: returns all the records
-
If the health check is unhealthy: returns the applicable value for the last healthy instance
-
If you didn't specify a health check configuration: returns all the records
For the current quota on the number of instances that you can register using the same namespace and using the same service, see Cloud Map quotas in the Cloud Map Developer Guide.
411 |
# File 'sig/client.rbs', line 411
def register_instance: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to the specified resource.
423 |
# File 'sig/client.rbs', line 423
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
438 |
# File 'sig/client.rbs', line 438
def untag_resource: (
|
#update_http_namespace(params = {}) ⇒ Types::UpdateHttpNamespaceResponse
Updates an HTTP namespace.
449 |
# File 'sig/client.rbs', line 449
def update_http_namespace: (
|
#update_instance_custom_health_status(params = {}) ⇒ Struct
Submits a request to change the health status of a custom health check to healthy or unhealthy.
You can use UpdateInstanceCustomHealthStatus to change the status
only for custom health checks, which you define using
HealthCheckCustomConfig when you create a service. You can't use it
to change the status for RouteĀ 53 health checks, which you define
using HealthCheckConfig.
For more information, see HealthCheckCustomConfig.
459 |
# File 'sig/client.rbs', line 459
def update_instance_custom_health_status: (
|
#update_private_dns_namespace(params = {}) ⇒ Types::UpdatePrivateDnsNamespaceResponse
Updates a private DNS namespace.
471 |
# File 'sig/client.rbs', line 471
def update_private_dns_namespace: (
|
#update_public_dns_namespace(params = {}) ⇒ Types::UpdatePublicDnsNamespaceResponse
Updates a public DNS namespace.
492 |
# File 'sig/client.rbs', line 492
def update_public_dns_namespace: (
|
#update_service(params = {}) ⇒ Types::UpdateServiceResponse
Submits a request to perform the following operations:
-
Update the TTL setting for existing
DnsRecordsconfigurations -
Add, update, or delete
HealthCheckConfigfor a specified serviceYou can't add, update, or delete a HealthCheckCustomConfigconfiguration.
For public and private DNS namespaces, note the following:
-
If you omit any existing
DnsRecordsorHealthCheckConfigconfigurations from anUpdateServicerequest, the configurations are deleted from the service. -
If you omit an existing
HealthCheckCustomConfigconfiguration from anUpdateServicerequest, the configuration isn't deleted from the service.
UpdateService and update settings in the following
scenarios:
-
When the service is associated with an HTTP namespace
-
When the service is associated with a shared namespace and contains instances that were registered by Amazon Web Services accounts other than the account making the
UpdateServicecall
When you update settings for a service, Cloud Map also updates the corresponding settings in all the records and health checks that were created by using the specified service.
513 |
# File 'sig/client.rbs', line 513
def update_service: (
|
#update_service_attributes(params = {}) ⇒ Struct
Submits a request to update a specified service to add service-level attributes.
538 |
# File 'sig/client.rbs', line 538
def update_service_attributes: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3740 3741 3742 |
# File 'lib/aws-sdk-servicediscovery/client.rb', line 3740 def waiter_names [] end |