Class: Aws::ServiceDiscovery::Types::ListInstancesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of instances that you want Cloud Map to return in the response to a ListInstances request. If you don’t specify a value for MaxResults, Cloud Map returns up to 100 instances.

Returns:

  • (Integer)


1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1766

class ListInstancesRequest < Struct.new(
  :service_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For the first ListInstances request, omit this value.

If more than MaxResults instances match the specified criteria, you can submit another ListInstances request to get the next group of results. Specify the value of NextToken from the previous response in the next request.

Returns:

  • (String)


1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1766

class ListInstancesRequest < Struct.new(
  :service_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#service_idString

The ID or Amazon Resource Name (ARN) of the service that you want to list instances for. For services created in a shared namespace, specify the service ARN. For more information about shared namespaces, see [Cross-account Cloud Map namespace sharing] in the *Cloud Map Developer Guide*.

[1]: docs.aws.amazon.com/cloud-map/latest/dg/sharing-namespaces.html

Returns:

  • (String)


1766
1767
1768
1769
1770
1771
1772
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1766

class ListInstancesRequest < Struct.new(
  :service_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end