Class: Aws::ServiceDiscovery::Types::ListOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceDiscovery::Types::ListOperationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::OperationFilter>
A complex type that contains specifications for the operations that you want to list, for example, operations that you started between a specified start date and end date.
-
#max_results ⇒ Integer
The maximum number of items that you want Cloud Map to return in the response to a
ListOperationsrequest. -
#next_token ⇒ String
For the first
ListOperationsrequest, omit this value.
Instance Attribute Details
#filters ⇒ Array<Types::OperationFilter>
A complex type that contains specifications for the operations that you want to list, for example, operations that you started between a specified start date and end date.
If you specify more than one filter, an operation must match all
filters to be returned by ListOperations.
1907 1908 1909 1910 1911 1912 1913 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1907 class ListOperationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items that you want Cloud Map to return in the
response to a ListOperations request. If you don't specify a
value for MaxResults, Cloud Map returns up to 100 operations.
1907 1908 1909 1910 1911 1912 1913 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1907 class ListOperationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListOperations request, omit this value.
If the response contains NextToken, submit another
ListOperations request to get the next group of results. Specify
the value of NextToken from the previous response in the next
request.
MaxResults operations and then filters them based
on the specified criteria. It's possible that no operations in the
first MaxResults operations matched the specified criteria but
that subsequent groups of MaxResults operations do contain
operations that match the criteria.
1907 1908 1909 1910 1911 1912 1913 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1907 class ListOperationsRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |