Class: Aws::ServiceDiscovery::Types::ListOperationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the response contains NextToken, submit another ListOperations request to get the next group of results. Specify the value of NextToken from the previous response in the next request.

<note markdown=“1”> Cloud Map gets MaxResults operations and then filters them based on the specified criteria. It’s possible that no operations in the first MaxResults operations matched the specified criteria but that subsequent groups of MaxResults operations do contain operations that match the criteria.

</note>

Returns:

  • (String)


1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1937

class ListOperationsResponse < Struct.new(
  :operations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::OperationSummary>

Summary information about the operations that match the specified criteria.

Returns:



1937
1938
1939
1940
1941
1942
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1937

class ListOperationsResponse < Struct.new(
  :operations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end