Class: Aws::ServiceDiscovery::Types::ListNamespacesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceDiscovery::Types::ListNamespacesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::NamespaceFilter>
A complex type that contains specifications for the namespaces that you want to list.
-
#max_results ⇒ Integer
The maximum number of namespaces that you want Cloud Map to return in the response to a
ListNamespacesrequest. -
#next_token ⇒ String
For the first
ListNamespacesrequest, omit this value.
Instance Attribute Details
#filters ⇒ Array<Types::NamespaceFilter>
A complex type that contains specifications for the namespaces that you want to list.
If you specify more than one filter, a namespace must match all filters to be returned by ListNamespaces.
1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1836 class ListNamespacesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of namespaces that you want Cloud Map to return in the response to a ListNamespaces request. If you don’t specify a value for MaxResults, Cloud Map returns up to 100 namespaces.
1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1836 class ListNamespacesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For the first ListNamespaces request, omit this value.
If the response contains NextToken, submit another ListNamespaces request to get the next group of results. Specify the value of NextToken from the previous response in the next request.
<note markdown=“1”> Cloud Map gets MaxResults namespaces and then filters them based on the specified criteria. It’s possible that no namespaces in the first MaxResults namespaces matched the specified criteria but that subsequent groups of MaxResults namespaces do contain namespaces that match the criteria.
</note>
1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1836 class ListNamespacesRequest < Struct.new( :next_token, :max_results, :filters) SENSITIVE = [] include Aws::Structure end |