Class: Aws::ServiceDiscovery::Types::ListNamespacesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceDiscovery::Types::ListNamespacesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#namespaces ⇒ Array<Types::NamespaceSummary>
An array that contains one
NamespaceSummaryobject for each namespace that matches the specified filter criteria. -
#next_token ⇒ String
If the response contains
NextToken, submit anotherListNamespacesrequest to get the next group of results.
Instance Attribute Details
#namespaces ⇒ Array<Types::NamespaceSummary>
An array that contains one NamespaceSummary object for each namespace that matches the specified filter criteria.
1866 1867 1868 1869 1870 1871 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1866 class ListNamespacesResponse < Struct.new( :namespaces, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the response contains NextToken, submit another ListNamespaces request to get the next group of results. Specify the value of NextToken from the previous response in the next request.
<note markdown=“1”> Cloud Map gets MaxResults namespaces and then filters them based on the specified criteria. It’s possible that no namespaces in the first MaxResults namespaces matched the specified criteria but that subsequent groups of MaxResults namespaces do contain namespaces that match the criteria.
</note>
1866 1867 1868 1869 1870 1871 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1866 class ListNamespacesResponse < Struct.new( :namespaces, :next_token) SENSITIVE = [] include Aws::Structure end |