Class: Aws::ServiceDiscovery::Types::ListOperationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceDiscovery::Types::ListOperationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the response contains
NextToken, submit anotherListOperationsrequest to get the next group of results. -
#operations ⇒ Array<Types::OperationSummary>
Summary information about the operations that match the specified criteria.
Instance Attribute Details
#next_token ⇒ String
If the response contains NextToken, submit another ListOperations request to get the next group of results. Specify the value of NextToken from the previous response in the next request.
<note markdown=“1”> Cloud Map gets MaxResults operations and then filters them based on the specified criteria. It’s possible that no operations in the first MaxResults operations matched the specified criteria but that subsequent groups of MaxResults operations do contain operations that match the criteria.
</note>
1937 1938 1939 1940 1941 1942 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1937 class ListOperationsResponse < Struct.new( :operations, :next_token) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::OperationSummary>
Summary information about the operations that match the specified criteria.
1937 1938 1939 1940 1941 1942 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 1937 class ListOperationsResponse < Struct.new( :operations, :next_token) SENSITIVE = [] include Aws::Structure end |