Method: Aws::ServiceDiscovery::Types::Operation#update_date
- Defined in:
- lib/aws-sdk-servicediscovery/types.rb
#update_date ⇒ Time
The date and time that the value of Status changed to the current value, in Unix date/time format and Coordinated Universal Time (UTC). The value of UpdateDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-servicediscovery/types.rb', line 2410 class Operation < Struct.new( :id, :owner_account, :type, :status, :error_message, :error_code, :create_date, :update_date, :targets) SENSITIVE = [] include Aws::Structure end |